require 'wonder_credentials/version'
require 'active_support/hash_with_indifferent_access'

class WonderCredentials
  class << self
    def get(path, options = {})
      new(options).get(path)
    end
  end

  def initialize(options = {})
    @options       = options.with_indifferent_access
    @default_value = @options[:default]
    @environment   = @options[:env] || @options[:env_fallback] || false
  end

  def inspect

  end

  def get(path)
    case path.class.name
    when 'String', 'Symbol'
      return get_string(path)
    when 'Array'
      return get_array(path)
    when 'Hash', 'ActiveSupport::HashWithIndifferentAccess'
      return get_hash(path)
    else
      raise "Unknown class name '#{path.class.name}' for WonderCredentials::Service#get, must be Array, Hash or String."

      return nil
    end
  end

  private

  def credentials
    (::Rails.application.credentials[::Rails.env.to_sym] || {}).with_indifferent_access
  end

  def get_string(path)
    value = nil
    unless path.empty?
      # com o path empty passaria a retornar todos os credentials
      variable_path = path.to_s.split(/\./).collect(&:to_sym)
      value = credentials
      variable_path.each { |k| value = value.try(:[], k) }
    end
    value = ENV[path] if @environment && value.blank?
    value = @default_value unless value
    value
  end

  def get_array(path)
    path.collect { |v| get(v) }
  end

  def get_hash(path)
    path.collect { |k, v| { k => get(v) } }.reduce(&:merge)
  end
end
